from flask import request, url_for, g
from typing import List, Optional

from mo.web import app


class MenuItem:
    url: str
    name: str
    active_prefix: str
    classes: List[str]

    def __init__(self, url: str, name: str, active_prefix: Optional[str] = None, classes: Optional[List[str]] = None):
        self.url = url
        self.name = name
        self.active_prefix = active_prefix or url
        self.classes = classes or []


def get_menu():
    if not g.user:
        items = [
            MenuItem(url_for('index'), "Domů")
        ]
    elif g.user.is_org or g.user.is_admin:
        items = [
            MenuItem(url_for('org_index'), "Domů"),
            MenuItem(url_for('org_place_root'), "Místa"),
            MenuItem(url_for('org_rounds'), "Soutěž"),
            MenuItem(url_for('org_users'), "Soutěžící"),
            MenuItem(url_for('org_orgs'), "Organizátoři"),
            MenuItem(url_for('org_jobs'), "Dávky"),
        ]
    else:
        items = [
            MenuItem(url_for('user_index'), "Domů"),
        ]

    # Login / user settings
    if g.user:
        name = g.user.full_name()
        if g.user.is_admin:
            name += " [admin]"
        items.append(MenuItem(url_for('user_settings'), name, classes=["right"]))
    else:
        items.append(MenuItem(url_for('login'), "Přihlásit se", active_prefix="/auth/", classes=["right"]))

    active = None
    for item in items:
        if not request.path.startswith(item.active_prefix):
            continue
        if active is None or len(item.active_prefix) > len(active.active_prefix):
            active = item
    if active is not None:
        active.classes.append("active")

    return items


app.jinja_env.globals.update(get_menu=get_menu)
