from flask import render_template, g
from sqlalchemy.orm import joinedload
import werkzeug.exceptions

import mo.db as db
from mo.web import app


@app.route('/org/log/<typ>/<int:id>/')
def org_log(typ: str, id: int):
    if not g.user.is_admin:
        raise werkzeug.exceptions.Forbidden()

    if not hasattr(db.LogType, typ):
        raise werkzeug.exceptions.NotFound()
    log_type = getattr(db.LogType, typ)

    sess = db.get_session()
    logs = (sess.query(db.Log)
            .filter_by(type=log_type, id=id)
            .options(joinedload(db.Log.user))
            .order_by(db.Log.changed_at.desc())
            .all())

    return render_template('org_log.html', type=log_type, id=id, logs=logs)
